@@ -3,10 +3,16 @@
 # 
 # Cosimo Streppone <cosimo@cpan.org>
 #
-# $Id$
 
 package Win32::API::Test;
 
+sub is_perl_64bit () {
+	use Config;
+	# was $Config{archname} =~ /x64/;
+	return 1 if $Config{ptrsize} == 8;
+	return;
+}
+
 sub compiler_name () {
 	use Config;
 	my $cc = $Config{ccname};
@@ -41,7 +47,7 @@ sub compiler_version_from_shell () {
 	{
 		my @ver = `$cc 2>&1`;            # Interesting output in STDERR
 		$ver = join('',@ver);
-		print 'VER:'.$ver.':'."\n";
+		#print 'VER:'.$ver.':'."\n";
 		if($ver =~ /Version (\d[\d\.]+)/ms )
 		{
 			$ver = $1;
@@ -68,9 +74,15 @@ sub compiler_version_from_shell () {
 	return($ver);
 }
 
-sub find_test_dll () {
+sub find_test_dll {
 	require File::Spec;
-	my $dll_name = $_[0];
+
+	my $default_dll_name = is_perl_64bit()
+		? 'API_test64.dll'
+		: 'API_test.dll';
+
+	my $dll_name = $_[0] || $default_dll_name;
+
 	my @paths = qw(.. ../t ../t/dll . ./dll ./t/dll);
 	while(my $path = shift @paths)
 	{
